Method: GedString#each
- Defined in:
- lib/gedcom/ged_string.rb
#each {|_self| ... } ⇒ Object
We aren’t an array, but to simplify some code, the method each is defined to return our 1 value.
43 44 45 |
# File 'lib/gedcom/ged_string.rb', line 43 def each yield self end |